diff --git a/GMW/GMW/GMW.csproj b/GMW/GMW/GMW.csproj
index 41664646..1c48d557 100644
--- a/GMW/GMW/GMW.csproj
+++ b/GMW/GMW/GMW.csproj
@@ -1114,6 +1114,7 @@
+
diff --git a/GMW/GMW/Web.config b/GMW/GMW/Web.config
index 9327c5ff..a1133eb2 100644
--- a/GMW/GMW/Web.config
+++ b/GMW/GMW/Web.config
@@ -60,7 +60,7 @@
-
+
@@ -216,14 +216,14 @@
-
+
-
+
-
+
diff --git a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
index f1613936..713db4cc 100644
--- a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
+++ b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
@@ -185,7 +185,7 @@
@@ -217,9 +217,9 @@
+ CommandName="Update" CommandArgument="resetListaPrelievo" ToolTip='<%# tooltipReset(Eval("CodTipoLista")) %>'
+ Visible='<%# ResetVisible(Eval("CodLista"), Eval("CodStatoLista")) %>' ImageUrl='<%# imgReset(Eval("CodTipoLista")) %>'
+ OnClick="img_Click" Enabled='<%# ResetEnabled(Eval("CodLista"), Eval("CodStatoLista"), Eval("CodTipoLista")) %>' />
diff --git a/GMW/GMW/WebUserControls/mod_nuovaListaPrelievo.ascx.cs b/GMW/GMW/WebUserControls/mod_nuovaListaPrelievo.ascx.cs
index dc4c3f11..52eb1bd5 100644
--- a/GMW/GMW/WebUserControls/mod_nuovaListaPrelievo.ascx.cs
+++ b/GMW/GMW/WebUserControls/mod_nuovaListaPrelievo.ascx.cs
@@ -61,7 +61,7 @@ namespace GMW.WebUserControls
protected bool particolareOk(string particolare)
{
bool answ = false;
- answ = (particolare.Length >= 12 && particolare.Substring(0, 1) == "P");
+ answ = DataProxy.obj.taAnagParticolari.getByParticolare(particolare).Rows.Count > 0;
return answ;
}
@@ -91,6 +91,7 @@ namespace GMW.WebUserControls
if (codImballo == "") codImballo = "*";
string codTipoLista = ddlTipoLista.SelectedValue;
numPezziDisp = MagClass.magazzino.numUdcDaPart(memLayer.ML.confReadString("CodCS"), txtParticolare.Text.Trim(), codEsponente, codFigura, codImballo, codTipoLista);
+ // sottraggo quelli
lblTotPz.Text = string.Format("{0} UDC ", numPezziDisp);
}
catch (Exception e)
diff --git a/GMW/GMW/bin/GMW.dll b/GMW/GMW/bin/GMW.dll
index 00ddf78d..da7026ad 100644
Binary files a/GMW/GMW/bin/GMW.dll and b/GMW/GMW/bin/GMW.dll differ
diff --git a/GMW/GMW/bin/GMW_data.dll b/GMW/GMW/bin/GMW_data.dll
index 8edf59cc..dcda1bee 100644
Binary files a/GMW/GMW/bin/GMW_data.dll and b/GMW/GMW/bin/GMW_data.dll differ
diff --git a/GMW/GMW/images/resetBozza_disabled.png b/GMW/GMW/images/resetBozza_disabled.png
new file mode 100644
index 00000000..85ab967f
Binary files /dev/null and b/GMW/GMW/images/resetBozza_disabled.png differ
diff --git a/GMW/GMW/mazzAppSettings.config b/GMW/GMW/mazzAppSettings.config
index 6f9ae32d..16cc2bc0 100644
--- a/GMW/GMW/mazzAppSettings.config
+++ b/GMW/GMW/mazzAppSettings.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/mazzAppSettingsSP.config b/GMW/GMW/mazzAppSettingsSP.config
index d37f4433..d652f58d 100644
--- a/GMW/GMW/mazzAppSettingsSP.config
+++ b/GMW/GMW/mazzAppSettingsSP.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/mazzAppSettingsSP_test.config b/GMW/GMW/mazzAppSettingsSP_test.config
index 4332edb5..b2ae588d 100644
--- a/GMW/GMW/mazzAppSettingsSP_test.config
+++ b/GMW/GMW/mazzAppSettingsSP_test.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/mazzAppSettingsTK.config b/GMW/GMW/mazzAppSettingsTK.config
index b238a39d..86c0b4e6 100644
--- a/GMW/GMW/mazzAppSettingsTK.config
+++ b/GMW/GMW/mazzAppSettingsTK.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/mazzAppSettingsTK_test.config b/GMW/GMW/mazzAppSettingsTK_test.config
index 6f9ae32d..16cc2bc0 100644
--- a/GMW/GMW/mazzAppSettingsTK_test.config
+++ b/GMW/GMW/mazzAppSettingsTK_test.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/obj/Debug/GMW.dll b/GMW/GMW/obj/Debug/GMW.dll
index 082f3cd5..da7026ad 100644
Binary files a/GMW/GMW/obj/Debug/GMW.dll and b/GMW/GMW/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache
index 6d279c7f..8a0a0254 100644
Binary files a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW/obj/Release/GMW.dll b/GMW/GMW/obj/Release/GMW.dll
index 00ddf78d..fb9dc1fd 100644
Binary files a/GMW/GMW/obj/Release/GMW.dll and b/GMW/GMW/obj/Release/GMW.dll differ
diff --git a/GMW/GMW/obj/Release/ResolveAssemblyReference.cache b/GMW/GMW/obj/Release/ResolveAssemblyReference.cache
index 87836bf4..48e476be 100644
Binary files a/GMW/GMW/obj/Release/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Release/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_Term/Web.config b/GMW/GMW_Term/Web.config
index 5902dca6..add4209a 100644
--- a/GMW/GMW_Term/Web.config
+++ b/GMW/GMW_Term/Web.config
@@ -129,14 +129,14 @@
-
+
-
+
-
+
diff --git a/GMW/GMW_Term/bin/GMW_Term.dll b/GMW/GMW_Term/bin/GMW_Term.dll
index bcfb6046..7b855be7 100644
Binary files a/GMW/GMW_Term/bin/GMW_Term.dll and b/GMW/GMW_Term/bin/GMW_Term.dll differ
diff --git a/GMW/GMW_Term/bin/GMW_data.dll b/GMW/GMW_Term/bin/GMW_data.dll
index 52875a2a..70e7c5c5 100644
Binary files a/GMW/GMW_Term/bin/GMW_data.dll and b/GMW/GMW_Term/bin/GMW_data.dll differ
diff --git a/GMW/GMW_Term/obj/Debug/GMW_Term.dll b/GMW/GMW_Term/obj/Debug/GMW_Term.dll
index 7d231fe1..7b855be7 100644
Binary files a/GMW/GMW_Term/obj/Debug/GMW_Term.dll and b/GMW/GMW_Term/obj/Debug/GMW_Term.dll differ
diff --git a/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache
index 423d3c83..fc24f651 100644
Binary files a/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_data/GMW_data.csproj b/GMW/GMW_data/GMW_data.csproj
index cc16303f..a00c3eb0 100644
--- a/GMW/GMW_data/GMW_data.csproj
+++ b/GMW/GMW_data/GMW_data.csproj
@@ -271,6 +271,7 @@
+
diff --git a/GMW/GMW_data/MagClass.cs b/GMW/GMW_data/MagClass.cs
index c37e824c..ce3d112b 100644
--- a/GMW/GMW_data/MagClass.cs
+++ b/GMW/GMW_data/MagClass.cs
@@ -1348,12 +1348,16 @@ namespace GMW_data
/// codice della lista di prelievo
/// cod operatore carrellista
///
- public esitoOperazione resetListaPrelievo(string CodCS, string CodLista, string CodSoggetto)
+ public esitoOperazione resetListaPrelievo(string CodCS, string CodLista, string CodSoggetto)
{
memLayer.ML.emptySessionVal("CodListaAttiva");
memLayer.ML.emptySessionVal("activeTask");
// da chiamare quando clicco e inizio lista prelievo .... vedi sopra
esitoOperazione answ = esitoOperazione.errore;
+ // posizione corrente dell'UDC
+ int idxPosizUdcCorr = 0;
+ int idxPosizioneTo = 0;
+ int idxCellaTo = 0;
try
{
// la query recupera la lista in base al CodLista
@@ -1370,18 +1374,21 @@ namespace GMW_data
string codTipoListaAttuale = riga.CodTipoLista;
// dal tipo lista determino l'evento
string codEvento = taTipoListaPrelievo.getByCodTipoLista(codTipoListaAttuale)[0].CodEvento;
- // dall'evento la posizione iniziale
- int idxPosizione = StateMachine.SM.taTTPE.getByEvento(codEvento)[0].IdxPosizione;
- // lo trasformo x avere la cella di destinazione...
- int idxCellaTo = taCelle.getFirstByPosizione(idxPosizione.ToString())[0].IdxCella;
- // leggo da righe lista prelievo il dato udc che mi serve
+ // leggo da righe lista prelievo il dato udc che mi serve
DS_magazzino.RigheListePrelievoDataTable tabellaRigheListaPrelievo = taRigheListePrelievo.getByCodListaPrelevate(CodLista);
DS_magazzino.RigheListePrelievoRow rigaListaPrelievo = tabellaRigheListaPrelievo[0];
// sposto ("metto a terra") gli UDC
+ string _UDC = "";
foreach (DS_magazzino.RigheListePrelievoRow row in tabellaRigheListaPrelievo.Rows)
{
// ricavo il codice UDC...
- string _UDC = row.UDC;
+ _UDC = row.UDC;
+ // posizione corrente
+ idxPosizUdcCorr = taCartellini.getDetailsUdcByUdc(_UDC)[0].IdxPosizione;
+ // calcolo posizione destinazione da state machine...
+ idxPosizioneTo = StateMachine.SM.taTTPE.getByEventoPosizione(codEvento, idxPosizUdcCorr)[0].IdxPosizioneTo;
+ // lo trasformo x avere la cella di destinazione...
+ idxCellaTo = taCelle.getFirstByPosizione(idxPosizioneTo.ToString())[0].IdxCella;
// sposto UDC
spostaUDC(CodCS, _UDC, idxCellaTo, false);
}
diff --git a/GMW/GMW_data/SqlScripts/V1.2/GMW_00421.sql b/GMW/GMW_data/SqlScripts/V1.2/GMW_00421.sql
new file mode 100644
index 00000000..ad23706b
--- /dev/null
+++ b/GMW/GMW_data/SqlScripts/V1.2/GMW_00421.sql
@@ -0,0 +1,323 @@
+set xact_abort on
+go
+
+begin transaction
+go
+
+UPDATE dbo.TipoListaPrelievo SET
+ enabled=0
+ WHERE CodTipoLista=N'00-Smart'
+go
+
+commit transaction
+go
+
+
+set xact_abort on;
+go
+
+begin transaction;
+go
+
+set ANSI_NULLS on;
+go
+
+/***************************************
+* STORED stp_selDestListePrelByConditio
+*
+* Ottiene i destinatari delle liste di prelievo data la condizione indicata
+*
+* Steamware, S.E.L.
+* mod: 2010.11.02
+*
+****************************************/
+alter PROCEDURE stp_selDestListePrelByConditio
+(
+ @conditio NVARCHAR(20)
+)
+AS
+
+IF (@conditio='01-PreFus')
+BEGIN
+ SELECT CAST('*' AS NVARCHAR(6)) AS value, CAST('*' AS NVARCHAR(50)) AS label, '01-PreFus' AS conditio
+END
+
+ELSE IF (@conditio='01-PreAnim')
+BEGIN
+ SELECT CAST(CodCliente AS NVARCHAR(6)) AS value, CAST(CodCliente AS NVARCHAR(6)) +'- ' +CAST(RagSociale AS NVARCHAR(50)) AS label, '01-PreAnim' AS conditio
+ FROM RilPro.AnagClienti
+ ORDER BY label
+END
+
+ELSE IF (@conditio='02-PreCli')
+BEGIN
+ SELECT CAST(CodCliente AS NVARCHAR(6)) AS value, CAST(CodCliente AS NVARCHAR(6)) +'- ' +CAST(RagSociale AS NVARCHAR(50)) AS label, '02-PreCli' AS conditio
+ FROM RilPro.AnagClienti
+ ORDER BY label
+END
+
+ELSE IF (@conditio='04-OdetSP')
+BEGIN
+ SELECT CAST(CodCliente AS NVARCHAR(6)) AS value, CAST(CodCliente AS NVARCHAR(6)) +'- ' +CAST(RagSociale AS NVARCHAR(50)) AS label, '04-OdetSP' AS conditio
+ FROM RilPro.AnagClienti
+ ORDER BY label
+END
+
+ELSE
+BEGIN
+ SELECT CAST(CodTerzista AS NVARCHAR(6)) AS value, CAST(CodTerzista AS NVARCHAR(6))+ '- '+CAST(DescTerzista AS NVARCHAR(50)) AS label, '03-TerWip' AS conditio
+ FROM RilPro.AnagDepositi
+ ORDER BY label
+END
+
+RETURN
+go
+
+commit;
+go
+
+
+set xact_abort on;
+go
+
+begin transaction;
+go
+
+set ANSI_NULLS on;
+go
+
+/***************************************
+* STORED stp_ParticolariOverviewPerListaPrelievo
+*
+* elenco di overview sull'impiego dei particolari (dettaglio a "maglie larghe") x una possibile lista di prelievo
+*
+* Steamware, S.E.L.
+* mod: 2010.05.31
+*
+****************************************/
+alter PROCEDURE stp_ParticolariOverviewPerListaPrelievo
+(
+ @Particolare VARCHAR(50),
+ @CodCS VARCHAR(2),
+ @Esponente NVARCHAR(6),
+ @Figura NVARCHAR(4),
+ @CodImballo NVARCHAR(15),
+ @CodTipoLista NVARCHAR (10)
+)
+AS
+ SELECT RilPro.AnagParticolari.Particolare, RilPro.AnagParticolari.DescParticolare, ISNULL(COUNT(dbo.ElencoCartellini.UDC), 0) AS NumUDC,
+ ISNULL(SUM(dbo.ElencoCartellini.Qta), 0) AS TotQta, ISNULL(COUNT(dbo.PosizioneUdcCorrente.IdxCella), 0) AS NumInMag
+ FROM RilPro.AnagParticolari LEFT OUTER JOIN
+ dbo.ElencoCartellini ON RilPro.AnagParticolari.Particolare = dbo.ElencoCartellini.Particolare LEFT OUTER JOIN
+ dbo.PosizioneUdcCorrente ON dbo.ElencoCartellini.UDC = dbo.PosizioneUdcCorrente.UDC
+ WHERE RilPro.AnagParticolari.CodCS = @CodCS AND
+ RilPro.AnagParticolari.Particolare = @Particolare AND
+ (IdxPosizione IN (SELECT tt.IdxPosizione
+ FROM TipoListaPrelievo tlp INNER JOIN TabTranPosizEventi tt ON tlp.CodEvento = tt.CodEvento
+ WHERE (tlp.CodTipoLista = @CodTipoLista))) AND
+ (dbo.ElencoCartellini.Figura = CASE WHEN @Figura = '*' THEN dbo.ElencoCartellini.Figura ELSE @Figura END) AND
+ (dbo.ElencoCartellini.Esponente = CASE WHEN @Esponente = '*' THEN dbo.ElencoCartellini.Esponente ELSE @Esponente END) AND
+ (dbo.ElencoCartellini.CodImballo = CASE WHEN @CodImballo = '*' THEN dbo.ElencoCartellini.CodImballo ELSE @CodImballo END)
+
+ AND ElencoCartellini.UDC NOT IN (
+ SELECT DISTINCT UDC
+ FROM RigheListePrelievo INNER JOIN ElencoListePrelievo
+ ON RigheListePrelievo.CodLista = ElencoListePrelievo.CodLista
+ WHERE (CodStatoLista > 1 AND Prelevato = 1)
+ )
+
+ GROUP BY RilPro.AnagParticolari.Particolare, RilPro.AnagParticolari.DescParticolare
+
+RETURN
+go
+
+commit;
+go
+
+
+
+set xact_abort on;
+go
+
+begin transaction;
+go
+
+set ANSI_NULLS on;
+go
+
+alter VIEW V_ParticolariOverview
+AS
+SELECT RilPro.AnagParticolari.Particolare, RilPro.AnagParticolari.DescParticolare, ISNULL(COUNT(dbo.ElencoCartellini.UDC), 0) AS NumUDC,
+ ISNULL(SUM(dbo.ElencoCartellini.Qta), 0) AS TotQta, ISNULL(COUNT(dbo.PosizioneUdcCorrente.IdxCella), 0) AS NumInMag
+FROM RilPro.AnagParticolari LEFT OUTER JOIN
+ dbo.ElencoCartellini ON RilPro.AnagParticolari.Particolare = dbo.ElencoCartellini.Particolare LEFT OUTER JOIN
+ dbo.PosizioneUdcCorrente ON dbo.ElencoCartellini.UDC = dbo.PosizioneUdcCorrente.UDC
+GROUP BY RilPro.AnagParticolari.Particolare, RilPro.AnagParticolari.DescParticolare
+go
+
+exec sp_updateextendedproperty 'MS_DiagramPane1', '[0E232FF0-B466-11cf-A24F-00AA00A3EFFF, 1.00]
+Begin DesignProperties =
+ Begin PaneConfigurations =
+ Begin PaneConfiguration = 0
+ NumPanes = 4
+ Configuration = "(H (1[41] 4[20] 2[13] 3) )"
+ End
+ Begin PaneConfiguration = 1
+ NumPanes = 3
+ Configuration = "(H (1 [50] 4 [25] 3))"
+ End
+ Begin PaneConfiguration = 2
+ NumPanes = 3
+ Configuration = "(H (1 [50] 2 [25] 3))"
+ End
+ Begin PaneConfiguration = 3
+ NumPanes = 3
+ Configuration = "(H (4 [30] 2 [40] 3))"
+ End
+ Begin PaneConfiguration = 4
+ NumPanes = 2
+ Configuration = "(H (1 [56] 3))"
+ End
+ Begin PaneConfiguration = 5
+ NumPanes = 2
+ Configuration = "(H (2 [66] 3))"
+ End
+ Begin PaneConfiguration = 6
+ NumPanes = 2
+ Configuration = "(H (4 [50] 3))"
+ End
+ Begin PaneConfiguration = 7
+ NumPanes = 1
+ Configuration = "(V (3))"
+ End
+ Begin PaneConfiguration = 8
+ NumPanes = 3
+ Configuration = "(H (1[56] 4[18] 2) )"
+ End
+ Begin PaneConfiguration = 9
+ NumPanes = 2
+ Configuration = "(H (1 [75] 4))"
+ End
+ Begin PaneConfiguration = 10
+ NumPanes = 2
+ Configuration = "(H (1[66] 2) )"
+ End
+ Begin PaneConfiguration = 11
+ NumPanes = 2
+ Configuration = "(H (4 [60] 2))"
+ End
+ Begin PaneConfiguration = 12
+ NumPanes = 1
+ Configuration = "(H (1) )"
+ End
+ Begin PaneConfiguration = 13
+ NumPanes = 1
+ Configuration = "(V (4))"
+ End
+ Begin PaneConfiguration = 14
+ NumPanes = 1
+ Configuration = "(V (2))"
+ End
+ ActivePaneConfig = 0
+ End
+ Begin DiagramPane =
+ Begin Origin =
+ Top = 0
+ Left = 0
+ End
+ Begin Tables =
+ Begin Table = "AnagParticolari (RilPro)"
+ Begin Extent =
+ Top = 6
+ Left = 38
+ Bottom = 191
+ Right = 208
+ End
+ DisplayFlags = 280
+ TopColumn = 0
+ End
+ Begin Table = "ElencoCartellini"
+ Begin Extent =
+ Top = 6
+ Left = 277
+ Bottom = 270
+ Right = 447
+ End
+ DisplayFlags = 280
+ TopColumn = 0
+ End
+ Begin Table = "PosizioneUdcCorrente"
+ Begin Extent =
+ Top = 7
+ Left = 533
+ Bottom = 136
+ Right = 703
+ End
+ DisplayFlags = 280
+ TopColumn = 0
+ End
+ End
+ End
+ Begin SQLPane =
+ End
+ Begin DataPane =
+ Begin ParameterDefaults = ""
+ End
+ Begin ColumnWidths = 9
+ Width = 284
+ Width = 1500
+ Width = 2580
+ Width = 1500
+ Width = 1500
+ Width = 1500
+ Width = 1500
+ Width = 1500
+ Width = 1500
+ End
+ End
+ Begin CriteriaPane =
+ Begin ColumnWidths = 12
+ Column = 1440
+ Alias = 900
+ Table = 1170
+ Output = 720
+ Append = 1400
+ NewValue = 1170
+ SortType = 1350
+ SortOrder = 1410
+ GroupBy = 1350
+ Filter = 1350
+ Or = 1350
+ Or = 1350
+ Or = 1350
+ End
+ End
+End
+', 'SCHEMA', 'dbo', 'VIEW', 'V_ParticolariOverview';
+go
+
+commit;
+go
+
+
+set xact_abort on
+go
+
+begin transaction
+go
+
+INSERT INTO dbo.TabTranPosizEventi
+ VALUES (N'MagPreAnim', -2, 2, 1)
+go
+
+commit transaction
+go
+
+
+
+
+
+
+-- registro versione...
+INSERT INTO [dbo].[LogUpdateDb] ([Versione],[Data]) VALUES(421, GETDATE())
+GO
diff --git a/GMW/GMW_data/bin/Debug/GMW_data.dll b/GMW/GMW_data/bin/Debug/GMW_data.dll
index 1ed9fb93..dcda1bee 100644
Binary files a/GMW/GMW_data/bin/Debug/GMW_data.dll and b/GMW/GMW_data/bin/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/bin/Release/GMW_data.dll b/GMW/GMW_data/bin/Release/GMW_data.dll
index 52875a2a..6ec7ba34 100644
Binary files a/GMW/GMW_data/bin/Release/GMW_data.dll and b/GMW/GMW_data/bin/Release/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/GMW_data.dll b/GMW/GMW_data/obj/Debug/GMW_data.dll
index 1ed9fb93..dcda1bee 100644
Binary files a/GMW/GMW_data/obj/Debug/GMW_data.dll and b/GMW/GMW_data/obj/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/TempPE/DS_Utility.Designer.cs.dll b/GMW/GMW_data/obj/Debug/TempPE/DS_Utility.Designer.cs.dll
index 68858602..a717cef2 100644
Binary files a/GMW/GMW_data/obj/Debug/TempPE/DS_Utility.Designer.cs.dll and b/GMW/GMW_data/obj/Debug/TempPE/DS_Utility.Designer.cs.dll differ
diff --git a/GMW/GMW_data/obj/Release/GMW_data.dll b/GMW/GMW_data/obj/Release/GMW_data.dll
index 52875a2a..6ec7ba34 100644
Binary files a/GMW/GMW_data/obj/Release/GMW_data.dll and b/GMW/GMW_data/obj/Release/GMW_data.dll differ
diff --git a/GMW/GMW_installer/GMW_installer.vdproj b/GMW/GMW_installer/GMW_installer.vdproj
index bb3e22a5..28a0498d 100644
--- a/GMW/GMW_installer/GMW_installer.vdproj
+++ b/GMW/GMW_installer/GMW_installer.vdproj
@@ -307,7 +307,7 @@
"Name" = "8:Microsoft Visual Studio"
"ProductName" = "8:GMW"
"ProductCode" = "8:{D4361E4A-D3A7-4744-9ADF-CF230244984A}"
- "PackageCode" = "8:{6AE7CCBC-9DE4-456A-BB66-196B903E2B62}"
+ "PackageCode" = "8:{B7395A9E-CCE7-4F46-8A7D-BC09C12CF78E}"
"UpgradeCode" = "8:{C9BC0732-DC92-4336-BAC9-A05A5D2A97C0}"
"RestartWWWService" = "11:TRUE"
"RemovePreviousVersions" = "11:TRUE"
diff --git a/GMW/GMW_installer/Release/GMW_installer.msi b/GMW/GMW_installer/Release/GMW_installer.msi
index 17721f34..555c4b12 100644
Binary files a/GMW/GMW_installer/Release/GMW_installer.msi and b/GMW/GMW_installer/Release/GMW_installer.msi differ
diff --git a/GMW/GMW_test_installer/GMW_test_installer.vdproj b/GMW/GMW_test_installer/GMW_test_installer.vdproj
index ffe00f5f..40805317 100644
--- a/GMW/GMW_test_installer/GMW_test_installer.vdproj
+++ b/GMW/GMW_test_installer/GMW_test_installer.vdproj
@@ -302,7 +302,7 @@
"Name" = "8:Microsoft Visual Studio"
"ProductName" = "8:GMW_test"
"ProductCode" = "8:{599D94EE-3F9A-4B04-9C4B-F65855BD5E73}"
- "PackageCode" = "8:{0D92F793-EE1D-45CA-A9C5-7D7971E06E2B}"
+ "PackageCode" = "8:{8F5AAEAF-2B44-44A0-8BA7-522045BBF611}"
"UpgradeCode" = "8:{6FD64E39-D93B-4ADA-ADF3-303A1BCA49C2}"
"RestartWWWService" = "11:TRUE"
"RemovePreviousVersions" = "11:TRUE"
@@ -753,7 +753,7 @@
{
"{5259A561-127C-4D43-A0A1-72F10C7B3BF8}:_110D6612090D4EDA92F772F593B23D78"
{
- "SourcePath" = "8:..\\..\\IISCustomActionVB\\IISConsoleVB\\obj\\Release\\IISConsoleVB.exe"
+ "SourcePath" = "8:..\\..\\IISCustomActionVB\\IISConsoleVB\\obj\\Debug\\IISConsoleVB.exe"
"TargetName" = "8:"
"Tag" = "8:"
"Folder" = "8:_D4983B53F0234BFF98835BF3AFECBB8D"
@@ -781,7 +781,7 @@
}
"{5259A561-127C-4D43-A0A1-72F10C7B3BF8}:_179F2C709A0749C4A5EBA956FADE7EE3"
{
- "SourcePath" = "8:..\\..\\SetDirectoryPermission\\obj\\Release\\SetDirectoryPermission.exe"
+ "SourcePath" = "8:..\\..\\SetDirectoryPermission\\obj\\Debug\\SetDirectoryPermission.exe"
"TargetName" = "8:"
"Tag" = "8:"
"Folder" = "8:_D4983B53F0234BFF98835BF3AFECBB8D"
diff --git a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
index 783309ff..1c399a9c 100644
--- a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
+++ b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
@@ -397,9 +397,9 @@ namespace GMW.WebUserControls
}
///
/// determina se sia eliminabile il record (=non usato)
///
- ///
+ /// stato lista
///
public bool delEnabled(object codStato)
{
@@ -463,25 +463,31 @@ namespace GMW.WebUserControls
///
/// determina se sia abilitato il pulsante x approvare e scaricare una lista di prelievo
///
- ///
+ /// stato lista
+ /// tipo lista di prelievo
///
- public bool ScaricaEnabled(object codStato)
+ public bool ScaricaEnabled(object codStato, object codTipo)
{
bool answ = false;
- try
+ // se la lista è di tipo smart NON si può comunque scaricare, cerco smart nel codice e NON lo deve contenere
+ if (!codTipo.ToString().Contains("Smart"))
{
- answ = ((int)codStato == (int)statoLista.completata);
+ try
+ {
+ answ = ((int)codStato == (int)statoLista.completata);
+ }
+ catch
+ { }
}
- catch
- { }
return answ;
}
///
/// determina se sia abilitato il pulsante x resettare una lista di prelievo a bozza
///
- ///
+ /// codice univoco lista prelievo
+ /// stato lista
///
- public bool ResetEnabled(object codLista, object codStato)
+ public bool ResetVisible(object codLista, object codStato)
{
bool answ = false;
// condizione: NON CI SIANO ODETTE
@@ -497,7 +503,73 @@ namespace GMW.WebUserControls
}
catch
{ }
- answ = (condOdette && condStato);
+ answ = (condOdette && condStato); // aggiungere controllo scrivibilità? isWritable();
+ return answ;
+ }
+ ///
+ /// determina se sia abilitato il pulsante x resettare una lista di prelievo a bozza
+ ///
+ /// codice univoco lista prelievo
+ /// stato lista
+ /// tipo lista di prelievo
+ ///
+ public bool ResetEnabled(object codLista, object codStato, object codTipo)
+ {
+ bool answ = false;
+ // se la lista è di tipo smart NON si può comunque scaricare, cerco smart nel codice e NON lo deve contenere
+ if (!codTipo.ToString().Contains("Smart"))
+ {
+ // condizione: NON CI SIANO ODETTE
+ bool condOdette = false; ;
+ // condizione: non in carico ad operatore
+ bool condStato = false; ;
+ try
+ {
+ // se >= completata resetto
+ condStato = ((int)codStato >= (int)statoLista.completata);
+ // cerco odette x la LDP, se NON ci sono è ok!
+ condOdette = !Odette.mgr.listaHasOdette(codLista.ToString());
+ }
+ catch
+ { }
+ answ = (condOdette && condStato);
+ }
+ return answ;
+ }
+ ///
+ /// sistema il tooltip di reset
+ ///
+ ///
+ ///
+ public string tooltipReset(object codTipo)
+ {
+ string answ = "";
+ if (!codTipo.ToString().Contains("Smart"))
+ {
+ answ = traduci("ResetListaPrelievo");
+ }
+ else
+ {
+ answ = traduci("ResetSmartNotEnabled");
+ }
+ return answ;
+ }
+ ///
+ /// imposta immagine reset
+ ///
+ ///
+ ///
+ public string imgReset(object codTipo)
+ {
+ string answ = "";
+ if (!codTipo.ToString().Contains("Smart"))
+ {
+ answ = "~/images/resetBozza.png";
+ }
+ else
+ {
+ answ = "~/images/resetBozza_disabled.png";
+ }
return answ;
}
///
@@ -397,9 +397,9 @@ namespace GMW.WebUserControls
}
///
- /// determina se sia eliminabile il record (=non usato)
+ /// determina se sia eliminabile il record (=non usato oppure smart)
///
diff --git a/GMW/GMW_Term/WebUserControls/mod_smartList.ascx.cs b/GMW/GMW_Term/WebUserControls/mod_smartList.ascx.cs
index 61a26531..4c3c3584 100644
--- a/GMW/GMW_Term/WebUserControls/mod_smartList.ascx.cs
+++ b/GMW/GMW_Term/WebUserControls/mod_smartList.ascx.cs
@@ -76,9 +76,8 @@ namespace GMW_Term.WebUserControls
MagClass.magazzino.attivaListaPrelievo(memLayer.ML.confReadString("CodCS"), currLDP, MagClass.magazzino.CodSoggCurrUser);
MagClass.magazzino.iniziaListaPrelievo(memLayer.ML.confReadString("CodCS"), currLDP, MagClass.magazzino.CodSoggCurrUser);
}
- // controllo se vada aggiunto UDC
- // cerco UDC nelle RLP
- if (MagClass.magazzino.taRigheListePrelievo.getByUdc(barcode).Rows.Count < 1)
+ // controllo se vada aggiunto UDC: lo cerco nelle RLP prelevate
+ if (MagClass.magazzino.taRigheListePrelievo.getPrelevateByUdc(barcode).Rows.Count < 1)
{
if (currLDP != "")
{
diff --git a/GMW/GMW_test_installer/Release/GMW_test_installer.msi b/GMW/GMW_test_installer/Release/GMW_test_installer.msi
index 1edd36a0..61ed2bc1 100644
Binary files a/GMW/GMW_test_installer/Release/GMW_test_installer.msi and b/GMW/GMW_test_installer/Release/GMW_test_installer.msi differ